@@ -1,9 +1,9 @@
 from os.path import dirname, basename, isfile
 from .person import Person
-from .objects import Institution, Experience, Education
+from .objects import Institution, Experience, Education, Contact
 from .company import Company
 
-__version__ = "2.6.0"
+__version__ = "2.7.1"
 
 import glob
 modules = glob.glob(dirname(__file__)+"/*.py")
